@@ -7,7 +7,7 @@ InternalMMPC.glmm = function(target, reps, group, dataset, max_k, threshold, tes
   cols <- dm[2]
   #univariate feature selection test
   if ( is.null(ini) ) {
-    univariateModels <- glmm.univregs(target = target, reps = reps, id = group, dataset = dataset, targetID = targetID, test = test, wei = wei, 
+    univariateModels <- MXM::glmm.univregs(target = target, reps = reps, id = group, dataset = dataset, targetID = targetID, test = test, wei = wei, 
                               slopes = slopes, ncores = ncores)
   } else  univariateModels <- ini
   
@@ -54,52 +54,52 @@ InternalMMPC.glmm = function(target, reps, group, dataset, max_k, threshold, tes
   
   while (loop) {
     #lets find the variable with the max min association
-    max_min_results = max_min_assoc.glmm(target, reps, group, dataset, test, wei, threshold, max_k, selectedVars, pvalues, stats, remainingVars, 
+    max_min_results <- max_min_assoc.glmm(target, reps, group, dataset, test, wei, threshold, max_k, selectedVars, pvalues, stats, remainingVars, 
                                          univariateModels, selectedVarsOrder, hash=hash, stat_hash=stat_hash, pvalue_hash=pvalue_hash, slopes = slopes);
-    selectedVar = max_min_results$selected_var;
-    selectedPvalue = max_min_results$selected_pvalue;
-    remainingVars = max_min_results$remainingVars;
-    pvalues = max_min_results$pvalues;
-    stats = max_min_results$stats;
-    stat_hash=max_min_results$stat_hash;
-    pvalue_hash=max_min_results$pvalue_hash;
+    selectedVar <- max_min_results$selected_var;
+    selectedPvalue <- max_min_results$selected_pvalue;
+    remainingVars <- max_min_results$remainingVars;
+    pvalues <- max_min_results$pvalues;
+    stats <- max_min_results$stats;
+    stat_hash <- max_min_results$stat_hash;
+    pvalue_hash <- max_min_results$pvalue_hash;
     #if the selected variable is associated with target , add it to the selected variables
     if (selectedPvalue <= threshold) {
-      selectedVars[selectedVar] = 1;
-      selectedVarsOrder[selectedVar] = max(selectedVarsOrder) + 1;
-      remainingVars[selectedVar] = 0;
+      selectedVars[selectedVar] <- 1
+      selectedVarsOrder[selectedVar] <- max(selectedVarsOrder) + 1
+      remainingVars[selectedVar] <- 0
     }
-    loop = any(as.logical(remainingVars));
+    loop <- any( as.logical(remainingVars) )
   }
   
-  selectedVarsOrder[which(!selectedVars)] = varsize;
-  numberofSelectedVars = sum(selectedVars); 
-  selectedVarsOrder = sort(selectedVarsOrder);
+  selectedVarsOrder[which(!selectedVars)] <- varsize;
+  numberofSelectedVars <- sum(selectedVars); 
+  selectedVarsOrder <- sort(selectedVarsOrder);
   #   selectedVars = selectedVarsOrder[1:numberofSelectedVars];
   #adjusting the results
   if (targetID > 0)  {
     toAdjust <- which(selectedVars > targetID);
-    selectedVars[toAdjust] = selectedVars[toAdjust] + 1;
+    selectedVars[toAdjust] <- selectedVars[toAdjust] + 1;
   }
   
-  results = NULL;
+  results <- NULL;
   results$selectedVars = which(selectedVars == 1);
-  svorder = sort(pvalues[results$selectedVars] , index.return = TRUE);
-  svorder = results$selectedVars[svorder$ix];
-  results$selectedVarsOrder = svorder;
-  hashObject = NULL;
-  hashObject$stat_hash = stat_hash;
-  hashObject$pvalue_hash = pvalue_hash;
-  results$hashObject = hashObject;
-  class(results$hashObject) = 'list';
-  class(results$univ) = 'list';
-  results$pvalues = pvalues;
-  results$stats = stats;
-  results$univ = univariateModels
-  results$max_k = max_k;
-  results$threshold = threshold;
-  results$slope = slopes
-  results$n.tests = length(stats) + length( hashObject$stat_hash )
+  svorder <- sort(pvalues[results$selectedVars] , index.return = TRUE);
+  svorder <- results$selectedVars[svorder$ix];
+  results$selectedVarsOrder <- svorder;
+  hashObject <- NULL;
+  hashObject$stat_hash <- stat_hash;
+  hashObject$pvalue_hash <- pvalue_hash;
+  results$hashObject <- hashObject;
+  class(results$hashObject) <- 'list';
+  class(results$univ) <- 'list';
+  results$pvalues <- pvalues;
+  results$stats <- stats;
+  results$univ <- univariateModels
+  results$max_k <- max_k;
+  results$threshold <- threshold;
+  results$slope <- slopes
+  results$n.tests <- length(stats) + length( hashObject$stat_hash )
   
   return(results);
 }
