@@ -3,6 +3,7 @@ MMPC.gee <- function(target, reps = NULL, group, dataset, max_k = 3, threshold =
   ##############################
   # initialization part of MMPC #
   ##############################
+  runtime <- proc.time()
   stat_hash <- NULL
   pvalue_hash <- NULL
 
@@ -104,10 +105,11 @@ MMPC.gee <- function(target, reps = NULL, group, dataset, max_k = 3, threshold =
   results <- InternalMMPC.gee(target, reps, group, dataset, max_k, log(threshold), test, ini, wei, user_test, hash, varsize, stat_hash, 
                              pvalue_hash, targetID, correl = correl, se = se, ncores = ncores);
   
-  MMPC.gee.output <- new("MMPC.gee.output", selectedVars = results$selectedVars, selectedVarsOrder=results$selectedVarsOrder, 
-                             hashObject=results$hashObject, pvalues=results$pvalues, stats=results$stats, univ = results$univ, 
-                             max_k=results$max_k, threshold = results$threshold, n.tests = results$n.tests, runtime=results$runtime, 
-                             test=ci_test, correl = results$correl, se = results$se);
+  runtime <- proc.time() - runtime
+  MMPC.gee.output <- new("MMPC.gee.output", selectedVars = results$selectedVars, selectedVarsOrder = results$selectedVarsOrder, 
+                             hashObject = results$hashObject, pvalues = results$pvalues, stats = results$stats, univ = results$univ, 
+                             max_k = results$max_k, threshold = results$threshold, n.tests = results$n.tests, runtime = runtime, 
+                             test = ci_test, correl = results$correl, se = results$se);
   return(MMPC.gee.output);
 }
 
